@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 from collections import defaultdict
 
 __all__ = ['EventEmitter', 'Event_emitter']
@@ -35,8 +37,8 @@ class EventEmitter(object):
         """
         handled = False
         # Pass the args to each function in the events dict
-        for fxn in self._events[event]:
-            fxn(*args, **kwargs)
+        for f in self._events[event]:
+            f(*args, **kwargs)
             handled = True
 
         if not handled and event == 'error':
@@ -56,21 +58,24 @@ class EventEmitter(object):
             self.on(event, _once(f))
 
 
-    def remove_listener(self, event, function):
+    def remove_listener(self, event, f):
         """
         Remove the function attached to `event`.
         """
-        self._events[event].remove(function)
+        self._events[event].remove(f)
 
-    def remove_all_listeners(self, event):
+    def remove_all_listeners(self, event=None):
+        """Remove all listeners attached to `event`. 
         """
-        Remove all listeners attached to `event`.
-        """
-        self._events[event] = []
+        if event is not None:
+            self._events[event] = []
+        else:
+            self._events = None
+            self._events = defaultdict(list)
 
     def listeners(self, event):
         return self._events[event]
 
 
 # Backwards capatiablity
-Event_emitter = EventEmitter
\ No newline at end of file
+Event_emitter = EventEmitter
