@@ -1,18 +1,21 @@
+# -*- coding: utf-8 -*-
+
 import nose.tools as nt
 from pyee import Event_emitter, EventEmitter
 
-# An exception, used to prove that an event handler fired.
-# Kinda hack-y, I know.
+
 class ItWorkedException(Exception):
+    """An exception, used to prove that an event handler fired.
+    Kinda hack-y, I know.
+    """
     pass
 
 def test_emit():
-    """
-    Test to show that event_emitters fire properly.
+    """Test that event_emitters fire properly.
     """
     ee = Event_emitter()
 
-    #Used in a decorator style.
+    # Used in a decorator style
     @ee.on('event')
     def event_handler(data, **kwargs):
         nt.assert_equals(data, 'emitter is emitted!')
@@ -20,10 +23,11 @@ def test_emit():
         if (kwargs['error']):
             raise ItWorkedException
 
-    #Making sure data is passed propers.
+    # Making sure data is passed propers
     ee.emit('event', 'emitter is emitted!', error=False)
 
-    # Some nose bullshit to check for the firings. "Hides" other exceptions.
+    # Some nose bullshit to check for the firings. 
+    # "Hides" other exceptions.
     with nt.assert_raises(ItWorkedException) as it_worked:
         ee.emit('event', 'emitter is emitted!', error=True)
 
@@ -43,18 +47,17 @@ def test_emit_error():
 def test_emit_return():
     ee = EventEmitter()
     
-    # make sure emission without callback retruns False
+    # make sure emitting without a callback returns False
     nt.assert_false(ee.emit('data'))
 
     # add a callback
     ee.on('data')(lambda: None)
 
-    # should return true now
+    # should return True now
     nt.assert_true(ee.emit('data'))
 
 def test_new_listener_event():
-    """
-    test for the 'new_listener' event
+    """Test the 'new_listener' event.
     """
 
     ee = Event_emitter()
@@ -70,8 +73,7 @@ def test_new_listener_event():
 
     
 def test_listener_removal():
-    """
-    tests to make sure we can remove listeners as appropriate.
+    """Tests that we can remove listeners (as appropriate).
     """
 
     ee = Event_emitter()
@@ -98,21 +100,20 @@ def test_listener_removal():
 
     nt.assert_equal(ee._events['event'], [first, second, third, fourth])
 
-    #uses the function itself to find/remove listener
+    # uses the function itself to find/remove listener
     ee.remove_listener('event', second)
     nt.assert_equal(ee._events['event'], [first, third, fourth])
 
-    #uses the function itself to find/remove listener
+    # uses the function itself to find/remove listener
     ee.remove_listener('event', first)
     nt.assert_equal(ee._events['event'], [third, fourth])
 
-    #remove ALL the listeners!
+    # Remove ALL listeners!
     ee.remove_all_listeners('event')
     nt.assert_equal(ee._events['event'], [])
 
 def test_once():
-    """
-    Test to show that the "once" method works propers.
+    """Test that `once()` method works propers.
     """
 
     # very similar to "test_emit" but also makes sure that the event
@@ -136,9 +137,9 @@ def test_once():
         ee.emit('event', 'emitter is emitted!', True)
 
 def test_listeners():
+    """Test that `listeners()` gives you access to the listeners array.
     """
-    Test to make sure that the listeners method gives you access to the listeners array.
-    """
+    
     ee = Event_emitter()
     @ee.on('event')
     def event_handler():
